@@ -264,12 +264,16 @@ class RestAPI(object):
 					id = subscription_plan['plan']['id']
 					try: subscriptions[email]["plans"][id]
 					except KeyError: subscriptions[email]["plans"][id] = {}
+					active = subscription_plan['plan']['active']
+					if active in [True, "true", "True", "TRUE"]: active = True
+					else: active = False
 					subscriptions[email]["plans"][id]["subscription_id"] = subscription_plan['id']
 					subscriptions[email]["plans"][id]["plan_id"] = subscription_plan['plan']['id']
 					subscriptions[email]["plans"][id]["plan_nickname"] = subscription_plan['plan']['nickname']
-					subscriptions[email]["plans"][id]["plan_active_status"] = subscription_plan['plan']['active']
+					subscriptions[email]["plans"][id]["plan_active_status"] = active
 
 			# success.
+			#print(json.dumps(subscriptions, indent=4))
 			return r3sponse.success_response("Successfully retrieved the subscriptions.", {
 				"subscriptions":subscriptions,
 			})
@@ -347,6 +351,7 @@ class RestAPI(object):
 			rank, plan, cancel_subs = None, None, {}
 			for uid, plans in subscriptions.items():
 				for plan, info in plans.items():
+					print("info:", info)
 					if info["plan_active_status"]:
 						response = self.__get_plan_by_plan_id__(info["plan_id"])
 						if response["error"] != None: 
